@@ -1,7 +1,7 @@
 from django.db import models
 
 from global_requests import get_thread_user
-from guardian_queryset.manager import GuardianManager
+from guardian_queryset.manager import GuardianManager, ForeignKeyGuardianManager
 from guardian_queryset.queryset import InvalidOperation
 from guardian_queryset.utils import assign_default_permissions, has_change_permissions, has_delete_permissions
 from django_utils.utils import is_anonymous_user
@@ -10,9 +10,12 @@ from django_utils.utils import is_anonymous_user
 class GuardianModel(models.Model):
 
     # __default_manager = _InternalGuardianManager()
+    is_foreign_key_guardian = False
+
     objects = GuardianManager()
     _objects = models.Manager()
 
+
     # @classmethod
     # def objects(cls, user):
     #     return cls._guardian_objects.with_user(user)
@@ -128,4 +131,12 @@ class GuardianModel(models.Model):
     #             errors[f.name] = e.error_list
     #
     #     if errors:
-    #         raise ValidationError(errors)
\ No newline at end of file
+    #         raise ValidationError(errors)
+
+class ForeignKeyGuardianModel(GuardianModel):
+    is_foreign_key_guardian = True
+
+    objects = ForeignKeyGuardianManager()
+
+    class Meta:
+        abstract = True
\ No newline at end of file
