@@ -12,6 +12,9 @@ def get_model_name(obj_or_query):
         return obj_or_query._meta.model.__name__.lower()
 
 def is_foreign_key_guardian_model(object):
+    if not hasattr(object, 'is_foreign_key_guardian'):
+        print(f'{object} does not explicitly indicate if it is a is_foreign_key_guardian or not. Assigning guardian permissions...')
+        return False
     return object.is_foreign_key_guardian
 
 def assign_default_permissions(user, object, model_name=None):
